# Fast Radial Symmetry Transform (FRST)

Implementation of fast radial symmetry transform in pure Python using OpenCV and numpy.

Based on:
Loy, G., & Zelinsky, A. (2002). A fast radial symmetry transform for detecting points of interest. Computer Vision, ECCV 2002.